@@ -14,14 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_CON_FTP_H__
 #define __GNOME_CMD_CON_FTP_H__
 
 #include "gnome-cmd-con.h"
 
-
 #define GNOME_CMD_CON_FTP(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_con_ftp_get_type (), GnomeCmdConFtp)
 #define GNOME_CMD_CON_FTP_CLASS(klass) \
@@ -48,50 +48,21 @@ struct _GnomeCmdConFtpClass
 };
 
 
-GtkType
-gnome_cmd_con_ftp_get_type (void);
+GtkType gnome_cmd_con_ftp_get_type (void);
 
-GnomeCmdConFtp *
-gnome_cmd_con_ftp_new     (const gchar *alias,
-                           const gchar *host_name,
-                           gint host_port,
-                           const gchar *user_name,
-                           const gchar *pw);
+GnomeCmdConFtp *gnome_cmd_con_ftp_new (const gchar *alias, const std::string &uri);
+GnomeCmdConFtp *gnome_cmd_con_ftp_new (const gchar *alias, const gchar *host, guint port, const gchar *user, const gchar *password, const gchar *remote_dir);
 
-void
-gnome_cmd_con_ftp_set_alias           (GnomeCmdConFtp *fs,
-                                       const gchar *alias);
+void gnome_cmd_con_ftp_set_alias (GnomeCmdConFtp *fs, const gchar *alias);
 
-void
-gnome_cmd_con_ftp_set_host_name       (GnomeCmdConFtp *fs,
-                                       const gchar *host_name);
+void gnome_cmd_con_ftp_set_host_name (GnomeCmdConFtp *fs, const gchar *host_name);
 
-void
-gnome_cmd_con_ftp_set_host_port       (GnomeCmdConFtp *fs,
-                                       gint host_port);
+void gnome_cmd_con_ftp_set_host_port (GnomeCmdConFtp *fs, gushort host_port);
 
-void
-gnome_cmd_con_ftp_set_user_name       (GnomeCmdConFtp *fs,
-                                       const gchar *user_name);
+void gnome_cmd_con_ftp_set_remote_dir (GnomeCmdConFtp *fs, const gchar *pw);
 
-void
-gnome_cmd_con_ftp_set_pw              (GnomeCmdConFtp *fs,
-                                       const gchar *pw);
+void gnome_cmd_con_ftp_set_user_name (GnomeCmdConFtp *fs, const gchar *user_name);
 
-const gchar *
-gnome_cmd_con_ftp_get_alias           (GnomeCmdConFtp *fs);
+void gnome_cmd_con_ftp_set_pw (GnomeCmdConFtp *fs, const gchar *pw);
 
-const gchar *
-gnome_cmd_con_ftp_get_host_name       (GnomeCmdConFtp *fs);
-
-gint
-gnome_cmd_con_ftp_get_host_port       (GnomeCmdConFtp *fs);
-
-const gchar *
-gnome_cmd_con_ftp_get_user_name       (GnomeCmdConFtp *fs);
-
-const gchar *
-gnome_cmd_con_ftp_get_pw              (GnomeCmdConFtp *fs);
-
-
-#endif //__GNOME_CMD_CON_FTP_H__
+#endif // __GNOME_CMD_CON_FTP_H__
