@@ -20,6 +20,7 @@
 #include <config.h>
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir.h"
+#include "gnome-cmd-file.h"
 #include "gnome-cmd-dir-pool.h"
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-con-smb.h"
@@ -44,6 +45,7 @@ enum
     FILE_CREATED,
     FILE_DELETED,
     FILE_CHANGED,
+    FILE_RENAMED,
     LIST_OK,
     LIST_FAILED,
     LAST_SIGNAL
@@ -72,12 +74,7 @@ static GnomeCmdFileClass *parent_class = NULL;
 static guint dir_signals[LAST_SIGNAL] = { 0 };
 
 
-static void
-monitor_callback (GnomeVFSMonitorHandle *handle,
-                  const gchar *monitor_uri,
-                  const gchar *info_uri,
-                  GnomeVFSMonitorEventType event_type,
-                  GnomeCmdDir *dir)
+static void monitor_callback (GnomeVFSMonitorHandle *handle, const gchar *monitor_uri, const gchar *info_uri, GnomeVFSMonitorEventType event_type, GnomeCmdDir *dir)
 {
     switch (event_type)
     {
@@ -97,6 +94,7 @@ monitor_callback (GnomeVFSMonitorHandle *handle,
         case GNOME_VFS_MONITOR_EVENT_STARTEXECUTING:
         case GNOME_VFS_MONITOR_EVENT_STOPEXECUTING:
             break;
+
         default:
             DEBUG('n', "Unknown monitor event %d\n", event_type);
     }
@@ -107,8 +105,7 @@ monitor_callback (GnomeVFSMonitorHandle *handle,
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     GnomeCmdDir *dir = GNOME_CMD_DIR (object);
 
@@ -126,10 +123,10 @@ destroy (GtkObject *object)
     dir->priv->handle->ref = NULL;
     handle_unref (dir->priv->handle);
 
-    if (dir->priv)
-        g_free (dir->priv);
+    g_free (dir->priv);
 
-    if (DEBUG_ENABLED ('c')) {
+    if (DEBUG_ENABLED ('c'))
+    {
         all_dirs = g_list_remove (all_dirs, dir);
         deleted_dirs_cnt++;
     }
@@ -139,8 +136,7 @@ destroy (GtkObject *object)
 }
 
 
-static void
-class_init (GnomeCmdDirClass *klass)
+static void class_init (GnomeCmdDirClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GnomeCmdFileClass *file_class = GNOME_CMD_FILE_CLASS (klass);
@@ -148,7 +144,7 @@ class_init (GnomeCmdDirClass *klass)
     parent_class = (GnomeCmdFileClass *) gtk_type_class (gnome_cmd_file_get_type ());
 
     dir_signals[FILE_CREATED] =
-        gtk_signal_new ("file_created",
+        gtk_signal_new ("file-created",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
             GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_created),
@@ -157,7 +153,7 @@ class_init (GnomeCmdDirClass *klass)
             1, GTK_TYPE_POINTER);
 
     dir_signals[FILE_DELETED] =
-        gtk_signal_new ("file_deleted",
+        gtk_signal_new ("file-deleted",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
             GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_deleted),
@@ -166,7 +162,7 @@ class_init (GnomeCmdDirClass *klass)
             1, GTK_TYPE_POINTER);
 
     dir_signals[FILE_CHANGED] =
-        gtk_signal_new ("file_changed",
+        gtk_signal_new ("file-changed",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
             GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_changed),
@@ -174,8 +170,17 @@ class_init (GnomeCmdDirClass *klass)
             GTK_TYPE_NONE,
             1, GTK_TYPE_POINTER);
 
+    dir_signals[FILE_RENAMED] =
+        gtk_signal_new ("file-renamed",
+            GTK_RUN_LAST,
+            G_OBJECT_CLASS_TYPE (object_class),
+            GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_renamed),
+            gtk_marshal_NONE__POINTER,
+            GTK_TYPE_NONE,
+            1, GTK_TYPE_POINTER);
+
     dir_signals[LIST_OK] =
-        gtk_signal_new ("list_ok",
+        gtk_signal_new ("list-ok",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
             GTK_SIGNAL_OFFSET (GnomeCmdDirClass, list_ok),
@@ -184,7 +189,7 @@ class_init (GnomeCmdDirClass *klass)
             1, GTK_TYPE_POINTER);
 
     dir_signals[LIST_FAILED] =
-        gtk_signal_new ("list_failed",
+        gtk_signal_new ("list-failed",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
             GTK_SIGNAL_OFFSET (GnomeCmdDirClass, list_failed),
@@ -196,13 +201,13 @@ class_init (GnomeCmdDirClass *klass)
     klass->file_created = NULL;
     klass->file_deleted = NULL;
     klass->file_changed = NULL;
+    klass->file_renamed = NULL;
     klass->list_ok = NULL;
     klass->list_failed = NULL;
 }
 
 
-static void
-init (GnomeCmdDir *dir)
+static void init (GnomeCmdDir *dir)
 {
     dir->priv = g_new0 (GnomeCmdDirPrivate, 1);
     dir->voffset = 0;
@@ -227,8 +232,7 @@ init (GnomeCmdDir *dir)
  * Public functions
  ***********************************/
 
-GtkType
-gnome_cmd_dir_get_type         (void)
+GtkType gnome_cmd_dir_get_type (void)
 {
     static GtkType type = 0;
 
@@ -252,27 +256,21 @@ gnome_cmd_dir_get_type         (void)
 }
 
 
-GnomeCmdDir *
-gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *parent)
+GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *parent)
 {
-    GnomeCmdDir *dir;
-    GnomeCmdCon *con;
-    GnomeCmdPath *path;
-    GnomeVFSURI *uri;
-    gchar *uri_str;
-
     g_return_val_if_fail (info != NULL, NULL);
     g_return_val_if_fail (GNOME_CMD_IS_DIR (parent), NULL);
 
-    con = gnome_cmd_dir_get_connection (parent);
-    path = gnome_cmd_path_get_child (gnome_cmd_dir_get_path (parent), info->name);
+    GnomeCmdCon *con = gnome_cmd_dir_get_connection (parent);
+    GnomeCmdPath *path = gnome_cmd_path_get_child (gnome_cmd_dir_get_path (parent), info->name);
 
-    uri = gnome_cmd_con_create_uri (con, path);
-    uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+    GnomeVFSURI *uri = gnome_cmd_con_create_uri (con, path);
+    gchar *uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
 
-    dir = gnome_cmd_con_cache_lookup (gnome_cmd_dir_get_connection (parent), uri_str);
+    GnomeCmdDir *dir = gnome_cmd_con_cache_lookup (gnome_cmd_dir_get_connection (parent), uri_str);
     g_free (uri_str);
     gnome_vfs_uri_unref (uri);
+
     if (dir)
     {
         gtk_object_destroy (GTK_OBJECT (path));
@@ -293,10 +291,7 @@ gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *parent)
 }
 
 
-GnomeCmdDir *
-gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info,
-                            GnomeCmdPath *path,
-                            GnomeCmdCon *con)
+GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info, GnomeCmdPath *path, GnomeCmdCon *con)
 {
     g_return_val_if_fail (info != NULL, NULL);
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
@@ -326,8 +321,7 @@ gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info,
 }
 
 
-GnomeCmdDir *
-gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path)
+GnomeCmdDir *gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
     g_return_val_if_fail (GNOME_CMD_IS_PATH (path), NULL);
@@ -376,34 +370,27 @@ gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path)
 }
 
 
-GnomeCmdDir *
-gnome_cmd_dir_get_parent (GnomeCmdDir *dir)
+GnomeCmdDir *gnome_cmd_dir_get_parent (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
     GnomeCmdPath *path = gnome_cmd_path_get_parent (dir->priv->path);
-    if (!path)
-        return NULL;
 
-    return gnome_cmd_dir_new (dir->priv->con, path);
+    return path ? gnome_cmd_dir_new (dir->priv->con, path) : NULL;
 }
 
 
-GnomeCmdDir *
-gnome_cmd_dir_get_child (GnomeCmdDir *dir, const gchar *child)
+GnomeCmdDir *gnome_cmd_dir_get_child (GnomeCmdDir *dir, const gchar *child)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
     GnomeCmdPath *path = gnome_cmd_path_get_child (dir->priv->path, child);
-    if (!path)
-        return NULL;
 
-    return gnome_cmd_dir_new (dir->priv->con, path);
+    return path ? gnome_cmd_dir_new (dir->priv->con, path) : NULL;
 }
 
 
-GnomeCmdCon *
-gnome_cmd_dir_get_connection (GnomeCmdDir *dir)
+GnomeCmdCon *gnome_cmd_dir_get_connection (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
@@ -419,8 +406,7 @@ Handle *gnome_cmd_dir_get_handle (GnomeCmdDir *dir)
 }
 
 
-void
-gnome_cmd_dir_ref (GnomeCmdDir *dir)
+void gnome_cmd_dir_ref (GnomeCmdDir *dir)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
@@ -428,8 +414,7 @@ gnome_cmd_dir_ref (GnomeCmdDir *dir)
 }
 
 
-void
-gnome_cmd_dir_unref (GnomeCmdDir *dir)
+void gnome_cmd_dir_unref (GnomeCmdDir *dir)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
@@ -437,8 +422,7 @@ gnome_cmd_dir_unref (GnomeCmdDir *dir)
 }
 
 
-GnomeVFSResult
-gnome_cmd_dir_get_files (GnomeCmdDir *dir, GList **files)
+GnomeVFSResult gnome_cmd_dir_get_files (GnomeCmdDir *dir, GList **files)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), GNOME_VFS_ERROR_BAD_PARAMETERS);
 
@@ -449,8 +433,7 @@ gnome_cmd_dir_get_files (GnomeCmdDir *dir, GList **files)
 }
 
 
-static GList *
-create_file_list (GnomeCmdDir *dir, GList *info_list)
+static GList *create_file_list (GnomeCmdDir *dir, GList *info_list)
 {
     GList *file_list = NULL;
 
@@ -480,7 +463,7 @@ create_file_list (GnomeCmdDir *dir, GList *info_list)
                 // This is a hack to make samba workgroups etc
                 // look like normal directories
                 info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
-                // Determining smb mime type: workgroup or server
+                // Determining smb MIME type: workgroup or server
                 gchar *uri_str = gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir));
 
                 info->mime_type = strcmp (uri_str, "smb:///") == 0 ? g_strdup ("x-directory/smb-workgroup") :
@@ -499,8 +482,7 @@ create_file_list (GnomeCmdDir *dir, GList *info_list)
 }
 
 
-static void
-on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult result)
+static void on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult result)
 {
     if (dir->state == DIR_STATE_LISTED)
     {
@@ -544,8 +526,7 @@ on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult result)
 }
 
 
-static void
-on_dir_list_cancel (GtkButton *btn, GnomeCmdDir *dir)
+static void on_dir_list_cancel (GtkButton *btn, GnomeCmdDir *dir)
 {
     if (dir->state == DIR_STATE_LISTING)
     {
@@ -558,8 +539,7 @@ on_dir_list_cancel (GtkButton *btn, GnomeCmdDir *dir)
 }
 
 
-static void
-create_list_progress_dialog (GnomeCmdDir *dir)
+static void create_list_progress_dialog (GnomeCmdDir *dir)
 {
     dir->dialog = gnome_cmd_dialog_new (NULL);
     gtk_widget_ref (dir->dialog);
@@ -588,8 +568,7 @@ create_list_progress_dialog (GnomeCmdDir *dir)
 }
 
 
-void
-gnome_cmd_dir_relist_files (GnomeCmdDir *dir, gboolean visprog)
+void gnome_cmd_dir_relist_files (GnomeCmdDir *dir, gboolean visprog)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
@@ -605,8 +584,7 @@ gnome_cmd_dir_relist_files (GnomeCmdDir *dir, gboolean visprog)
 }
 
 
-void
-gnome_cmd_dir_list_files (GnomeCmdDir *dir, gboolean visprog)
+void gnome_cmd_dir_list_files (GnomeCmdDir *dir, gboolean visprog)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
@@ -623,8 +601,7 @@ gnome_cmd_dir_list_files (GnomeCmdDir *dir, gboolean visprog)
 }
 
 
-GnomeCmdPath *
-gnome_cmd_dir_get_path (GnomeCmdDir *dir)
+GnomeCmdPath *gnome_cmd_dir_get_path (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
@@ -632,8 +609,7 @@ gnome_cmd_dir_get_path (GnomeCmdDir *dir)
 }
 
 
-void
-gnome_cmd_dir_set_path (GnomeCmdDir *dir, GnomeCmdPath *path)
+void gnome_cmd_dir_set_path (GnomeCmdDir *dir, GnomeCmdPath *path)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
@@ -645,8 +621,7 @@ gnome_cmd_dir_set_path (GnomeCmdDir *dir, GnomeCmdPath *path)
 }
 
 
-void
-gnome_cmd_dir_update_path (GnomeCmdDir *dir)
+void gnome_cmd_dir_update_path (GnomeCmdDir *dir)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
@@ -660,8 +635,7 @@ gnome_cmd_dir_update_path (GnomeCmdDir *dir)
 }
 
 
-gchar *
-gnome_cmd_dir_get_display_path (GnomeCmdDir *dir)
+gchar *gnome_cmd_dir_get_display_path (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
@@ -689,8 +663,7 @@ gchar *gnome_cmd_dir_get_uri_str (GnomeCmdDir *dir)
 }
 
 
-GnomeVFSURI *
-gnome_cmd_dir_get_child_uri (GnomeCmdDir *dir, const gchar *filename)
+GnomeVFSURI *gnome_cmd_dir_get_child_uri (GnomeCmdDir *dir, const gchar *filename)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
@@ -702,8 +675,7 @@ gnome_cmd_dir_get_child_uri (GnomeCmdDir *dir, const gchar *filename)
 }
 
 
-gchar *
-gnome_cmd_dir_get_child_uri_str (GnomeCmdDir *dir, const gchar *filename)
+gchar *gnome_cmd_dir_get_child_uri_str (GnomeCmdDir *dir, const gchar *filename)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
@@ -715,7 +687,7 @@ gnome_cmd_dir_get_child_uri_str (GnomeCmdDir *dir, const gchar *filename)
 }
 
 
-GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, string &filename)
+GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, string absolute_filename)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
@@ -738,13 +710,13 @@ GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, string &file
         g_free (mime_type);
 
         gchar *server_and_share = gnome_vfs_uri_to_string (dir_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-        stringify (filename, g_build_filename (server_and_share, filename.c_str(), NULL));
+        stringify (absolute_filename, g_build_filename (server_and_share, absolute_filename.c_str(), NULL));
         g_free (server_and_share);
     }
 
     gnome_vfs_uri_unref (dir_uri);
 
-    GnomeCmdPath *path = gnome_cmd_con_create_path (dir->priv->con, filename.c_str());
+    GnomeCmdPath *path = gnome_cmd_con_create_path (dir->priv->con, absolute_filename.c_str());
     GnomeVFSURI *uri = gnome_cmd_con_create_uri (dir->priv->con, path);
 
     gtk_object_destroy (GTK_OBJECT (path));
@@ -753,8 +725,7 @@ GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, string &file
 }
 
 
-static gboolean
-file_already_exists (GnomeCmdDir *dir, const gchar *uri_str)
+static gboolean file_already_exists (GnomeCmdDir *dir, const gchar *uri_str)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), TRUE);
     g_return_val_if_fail (uri_str != NULL, TRUE);
@@ -769,23 +740,20 @@ file_already_exists (GnomeCmdDir *dir, const gchar *uri_str)
  */
 void gnome_cmd_dir_file_created (GnomeCmdDir *dir, const gchar *uri_str)
 {
-    GnomeVFSURI *uri;
-    GnomeVFSResult res;
-    GnomeVFSFileInfo *info;
-    GnomeCmdFile *finfo;
-    GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS|GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
-
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
     g_return_if_fail (uri_str != NULL);
 
     if (file_already_exists (dir, uri_str))
         return;
 
-    uri = gnome_vfs_uri_new (uri_str);
-    info = gnome_vfs_file_info_new ();
-    res = gnome_vfs_get_file_info_uri (uri, info, infoOpts);
+    GnomeVFSURI *uri = gnome_vfs_uri_new (uri_str);
+    GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
+    GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS|GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
+    GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, infoOpts);
     gnome_vfs_uri_unref (uri);
 
+    GnomeCmdFile *finfo;
+
     if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
         finfo = GNOME_CMD_FILE (gnome_cmd_dir_new_from_info (info, dir));
     else
@@ -807,7 +775,8 @@ void gnome_cmd_dir_file_deleted (GnomeCmdDir *dir, const gchar *uri_str)
 
     GnomeCmdFile *finfo = gnome_cmd_file_collection_lookup (dir->priv->file_collection, uri_str);
 
-    g_return_if_fail (GNOME_CMD_IS_FILE (finfo));
+    if (!GNOME_CMD_IS_FILE (finfo))
+        return;
 
     gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_DELETED], finfo);
 
@@ -839,17 +808,22 @@ void gnome_cmd_dir_file_changed (GnomeCmdDir *dir, const gchar *uri_str)
 }
 
 
-void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *finfo)
+void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *finfo, const gchar *old_uri_str)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
     g_return_if_fail (GNOME_CMD_IS_FILE (finfo));
+    g_return_if_fail (old_uri_str!=NULL);
 
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_CHANGED], finfo);
+    if (GNOME_CMD_IS_DIR (finfo))
+        gnome_cmd_con_remove_from_cache (dir->priv->con, old_uri_str);
+
+    gnome_cmd_file_collection_remove_by_uri (dir->priv->file_collection, old_uri_str);
+    gnome_cmd_file_collection_add (dir->priv->file_collection, finfo);
+    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_RENAMED], finfo);
 }
 
 
-gboolean
-gnome_cmd_dir_uses_fam (GnomeCmdDir *dir)
+gboolean gnome_cmd_dir_uses_fam (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), FALSE);
 
@@ -857,13 +831,12 @@ gnome_cmd_dir_uses_fam (GnomeCmdDir *dir)
 }
 
 
-void
-gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir)
+void gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir)
 {
-    GnomeVFSResult result;
-
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
+    GnomeVFSResult result;
+
     if (dir->priv->monitor_users == 0)
     {
         gchar *uri_str = gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir));
@@ -887,8 +860,7 @@ gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir)
 }
 
 
-void
-gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir)
+void gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
@@ -915,8 +887,7 @@ gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir)
 }
 
 
-gboolean
-gnome_cmd_dir_is_local (GnomeCmdDir *dir)
+gboolean gnome_cmd_dir_is_local (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), FALSE);
 
