@@ -131,8 +131,7 @@ create_general_tab (GtkWidget *parent)
 }
 
 
-static void
-store_general_options (GnomeCmdOptionsDialog *dialog)
+inline void store_general_options (GnomeCmdOptionsDialog *dialog)
 {
     GtkWidget *rmb_popup_radio = lookup_widget (GTK_WIDGET (dialog), "rmb_popup_radio");
     GtkWidget *ft_regex_radio = lookup_widget (GTK_WIDGET (dialog), "ft_regex_radio");
@@ -152,7 +151,7 @@ store_general_options (GnomeCmdOptionsDialog *dialog)
 
     gnome_cmd_data_set_case_sens_sort (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (case_sens_check)));
     gnome_cmd_data_set_dir_cache_size (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dir_cache_size)));
-    gnome_cmd_data_set_alt_quick_search(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(alt_quick_search)));
+    gnome_cmd_data_set_alt_quick_search (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (alt_quick_search)));
 }
 
 
@@ -204,11 +203,13 @@ create_format_tab (GtkWidget *parent)
     cat = create_category (parent, cat_box, _("Size display mode"));
     gtk_box_pack_start (GTK_BOX (vbox), cat, FALSE, TRUE, 0);
 
+    // Translators: 'Powered' refers to the mode of file size display (here - display using units of data: kB, MB, GB, ...)
     radio = create_radio (parent, NULL, _("Powered"), "size_powered_radio");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
     if (gnome_cmd_data_get_size_disp_mode () == GNOME_CMD_SIZE_DISP_MODE_POWERED)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
 
+    // Translators: '<locale>' refers to the mode of file size display (here - use current locale settings)
     radio = create_radio (parent, get_radio_group (radio), _("<locale>"), "size_locale_radio");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
     if (gnome_cmd_data_get_size_disp_mode () == GNOME_CMD_SIZE_DISP_MODE_LOCALE)
@@ -278,8 +279,7 @@ create_format_tab (GtkWidget *parent)
 }
 
 
-static void
-store_format_options (GnomeCmdOptionsDialog *dialog)
+inline void store_format_options (GnomeCmdOptionsDialog *dialog)
 {
     GtkWidget *size_powered_radio = lookup_widget (GTK_WIDGET (dialog), "size_powered_radio");
     GtkWidget *size_locale_radio = lookup_widget (GTK_WIDGET (dialog), "size_locale_radio");
@@ -586,8 +586,7 @@ create_layout_tab (GtkWidget *parent)
 }
 
 
-static void
-store_layout_options (GnomeCmdOptionsDialog *dialog)
+inline void store_layout_options (GnomeCmdOptionsDialog *dialog)
 {
     const gchar *list_font;
 
@@ -705,8 +704,7 @@ create_confirmation_tab (GtkWidget *parent)
 }
 
 
-static void
-store_confirmation_options (GnomeCmdOptionsDialog *dialog)
+inline void store_confirmation_options (GnomeCmdOptionsDialog *dialog)
 {
     GtkWidget *confirm_delete_check = lookup_widget (GTK_WIDGET (dialog), "confirm_delete_check");
     GtkWidget *confirm_copy_silent = lookup_widget (GTK_WIDGET (dialog), "copy_overwrite_silently");
@@ -733,6 +731,7 @@ store_confirmation_options (GnomeCmdOptionsDialog *dialog)
         gnome_cmd_data_set_confirm_overwrite_move (GNOME_CMD_CONFIRM_OVERWRITE_SKIP_ALL);
 }
 
+
 /***********************************************************************
  *
  *  The Filter tab
@@ -849,8 +848,7 @@ create_filter_tab (GtkWidget *parent)
 }
 
 
-static void
-store_filter_options (GnomeCmdOptionsDialog *dialog)
+inline void store_filter_options (GnomeCmdOptionsDialog *dialog)
 {
     GtkWidget *hide_unknown_check;
     GtkWidget *hide_directory_check;
@@ -911,6 +909,63 @@ store_filter_options (GnomeCmdOptionsDialog *dialog)
 
 
 
+/***********************************************************************
+ *
+ *  The Network tab
+ *
+ **********************************************************************/
+
+static GtkWidget*
+create_network_tab (GtkWidget *parent)
+{
+    GtkWidget *frame, *hbox, *vbox, *cat, *cat_box;
+    GtkWidget *table, *label, *entry;
+    GtkWidget *radio, *check;
+
+    frame = create_tabframe (parent);
+    hbox = create_tabhbox (parent);
+    gtk_container_add (GTK_CONTAINER (frame), hbox);
+    vbox = create_tabvbox (parent);
+    gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
+
+
+    // GNOME Keyring Manager
+
+    cat_box = create_vbox (parent, FALSE, 0);
+    cat = create_category (parent, cat_box, _("Authentication"));
+    gtk_box_pack_start (GTK_BOX (vbox), cat, FALSE, TRUE, 0);
+
+    check = create_check (parent, _("Use GNOME Keyring Manager for authentication"), "use_auth_manager");
+    gtk_box_pack_start (GTK_BOX (cat_box), check, FALSE, TRUE, 0);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), gnome_cmd_data_get_use_gnome_auth_manager ());
+
+
+    // Anonymous FTP password options
+
+    table = create_table (parent, 1, 2);
+    cat = create_category (parent, table, _("Anonymous FTP access"));
+    gtk_box_pack_start (GTK_BOX (vbox), cat, FALSE, FALSE, 0);
+
+    label = create_label (parent, _("Password:"));
+    table_add (table, label, 0, 0, GTK_FILL);
+
+    entry = create_entry (parent, "anonymous_ftp_password", gnome_cmd_data_get_ftp_anonymous_password ());
+    table_add (table, entry, 1, 0, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
+
+    return frame;
+}
+
+
+inline void store_network_options (GnomeCmdOptionsDialog *dialog)
+{
+    GtkWidget *use_auth_manager_check = lookup_widget (GTK_WIDGET (dialog), "use_auth_manager");
+    GtkWidget *entry = lookup_widget (GTK_WIDGET (dialog), "anonymous_ftp_password");
+
+    gnome_cmd_data_set_use_gnome_auth_manager (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (use_auth_manager_check)));
+    gnome_cmd_data_set_ftp_anonymous_password (gtk_entry_get_text (GTK_ENTRY (entry)));
+}
+
+
 /***********************************************************************
  *
  *  The Programs tab
@@ -1251,13 +1306,13 @@ on_app_moved (GtkCList *clist, gint arg1, gint arg2, GtkWidget *frame)
 }
 
 
-static void
-on_app_remove (GtkWidget *button, GtkWidget *frame)
+static void on_app_remove (GtkWidget *button, GtkWidget *frame)
 {
     GnomeCmdApp *app;
     GtkCList *clist = GTK_CLIST (lookup_widget (frame, "app_clist"));
 
-    if (clist->focus_row >= 0) {
+    if (clist->focus_row >= 0)
+    {
         app = (GnomeCmdApp *) gtk_clist_get_row_data (clist, clist->focus_row);
         gnome_cmd_data_remove_fav_app (app);
         gtk_clist_remove (clist, clist->focus_row);
@@ -1275,8 +1330,7 @@ on_app_move_up (GtkWidget *button, GtkWidget *frame)
 }
 
 
-static void
-on_app_move_down (GtkWidget *button, GtkWidget *frame)
+static void on_app_move_down (GtkWidget *button, GtkWidget *frame)
 {
     GtkCList *clist = GTK_CLIST (lookup_widget (frame, "app_clist"));
 
@@ -1285,8 +1339,7 @@ on_app_move_down (GtkWidget *button, GtkWidget *frame)
 }
 
 
-static GtkWidget*
-create_programs_tab (GtkWidget *parent)
+static GtkWidget *create_programs_tab (GtkWidget *parent)
 {
     GtkWidget *frame, *hbox, *vbox, *cat, *table;
     GtkWidget *entry, *button, *label, *clist, *bbox, *check;
@@ -1348,17 +1401,17 @@ create_programs_tab (GtkWidget *parent)
     bbox = create_vbuttonbox (parent);
     gtk_box_pack_start (GTK_BOX (hbox), bbox, FALSE, TRUE, 0);
 
-    button = create_button (parent, _("_Add..."), GTK_SIGNAL_FUNC (on_app_add));
+    button = create_stock_button (parent, GTK_STOCK_ADD, GTK_SIGNAL_FUNC (on_app_add));
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_container_add (GTK_CONTAINER (bbox), button);
 
-    button = create_button (parent, _("_Edit..."), GTK_SIGNAL_FUNC (on_app_edit));
+    button = create_stock_button (parent, GTK_STOCK_EDIT, GTK_SIGNAL_FUNC (on_app_edit));
     gtk_object_set_data (GTK_OBJECT (parent), "edit_app_button", button);
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_widget_set_sensitive (button, FALSE);
     gtk_container_add (GTK_CONTAINER (bbox), button);
 
-    button = create_button (parent, _("_Remove"), GTK_SIGNAL_FUNC (on_app_remove));
+    button = create_stock_button (parent, GTK_STOCK_REMOVE, GTK_SIGNAL_FUNC (on_app_remove));
     gtk_object_set_data (GTK_OBJECT (parent), "remove_app_button", button);
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_widget_set_sensitive (button, FALSE);
@@ -1380,8 +1433,7 @@ create_programs_tab (GtkWidget *parent)
 }
 
 
-static void
-store_programs_options (GnomeCmdOptionsDialog *dialog)
+inline void store_programs_options (GnomeCmdOptionsDialog *dialog)
 {
     GtkWidget *entry1 = lookup_widget (GTK_WIDGET (dialog), "viewer");
     GtkWidget *entry2 = lookup_widget (GTK_WIDGET (dialog), "editor");
@@ -1406,8 +1458,7 @@ store_programs_options (GnomeCmdOptionsDialog *dialog)
  *
  **********************************************************************/
 
-static void
-add_device_to_list (GtkCList *clist, GnomeCmdConDevice *dev)
+static void add_device_to_list (GtkCList *clist, GnomeCmdConDevice *dev)
 {
     gchar *text[2];
     gint row;
@@ -1450,16 +1501,13 @@ update_device_in_list (GtkCList *clist, GnomeCmdConDevice *dev,
 }
 
 
-static void
-on_device_dialog_cancel (GtkButton *button, GtkWidget *dialog)
+static void on_device_dialog_cancel (GtkButton *button, GtkWidget *dialog)
 {
     gtk_widget_destroy (dialog);
 }
 
 
-static void
-get_device_dialog_values (GtkWidget *dialog, gchar **alias, gchar **device,
-                          gchar **mountp, gchar **icon_path)
+static void get_device_dialog_values (GtkWidget *dialog, gchar **alias, gchar **device, gchar **mountp, gchar **icon_path)
 {
     GtkWidget *alias_entry = lookup_widget (dialog, "alias_entry");
     GtkWidget *device_entry = lookup_widget (dialog, "device_entry");
@@ -1473,8 +1521,7 @@ get_device_dialog_values (GtkWidget *dialog, gchar **alias, gchar **device,
 }
 
 
-static void
-on_add_device_dialog_ok (GtkButton *button, GtkWidget *dialog)
+static void on_add_device_dialog_ok (GtkButton *button, GtkWidget *dialog)
 {
     GnomeCmdConDevice *dev;
     gchar *alias, *device, *mountp, *icon_path;
@@ -1489,7 +1536,7 @@ on_add_device_dialog_ok (GtkButton *button, GtkWidget *dialog)
     add_device_to_list (GTK_CLIST (clist), GNOME_CMD_CON_DEVICE (dev));
     gtk_widget_destroy (dialog);
 
-    gnome_cmd_con_list_add_device (gnome_cmd_data_get_con_list (), dev);
+    gnome_cmd_con_list_add_device (gnome_cmd_con_list_get (), dev);
 
     g_free (alias);
     g_free (device);
@@ -1614,9 +1661,9 @@ on_device_remove (GtkWidget *button, GtkWidget *frame)
     if (clist->focus_row >= 0)
     {
         GnomeCmdConDevice *dev = GNOME_CMD_CON_DEVICE (gtk_clist_get_row_data (clist, clist->focus_row));
-        gnome_cmd_con_list_remove_device (gnome_cmd_data_get_con_list (), dev);
+        gnome_cmd_con_list_remove_device (gnome_cmd_con_list_get (), dev);
         gtk_clist_remove (clist, clist->focus_row);
-        gnome_cmd_con_list_remove_device (gnome_cmd_data_get_con_list (), dev);
+        gnome_cmd_con_list_remove_device (gnome_cmd_con_list_get (), dev);
     }
 }
 
@@ -1639,8 +1686,7 @@ on_device_selected (GtkCList *clist, gint row, gint column,
 static void
 on_device_moved (GtkCList *clist, gint arg1, gint arg2, GtkWidget *frame)
 {
-    GList *list = gnome_cmd_con_list_get_all_dev (gnome_cmd_data_get_con_list ());
-    gpointer data;
+    GList *list = gnome_cmd_con_list_get_all_dev (gnome_cmd_con_list_get ());
 
     if (!list
         || MAX (arg1, arg2) >= g_list_length (list)
@@ -1648,12 +1694,12 @@ on_device_moved (GtkCList *clist, gint arg1, gint arg2, GtkWidget *frame)
         || arg1 == arg2)
         return;
 
-    data = g_list_nth_data (list, arg1);
+    gpointer data = g_list_nth_data (list, arg1);
     list = g_list_remove (list, data);
 
     list = g_list_insert (list, data, arg2);
 
-    gnome_cmd_con_list_set_all_dev (gnome_cmd_data_get_con_list (), list);
+    gnome_cmd_con_list_set_all_dev (gnome_cmd_con_list_get (), list);
 }
 
 
@@ -1706,17 +1752,17 @@ create_devices_tab (GtkWidget *parent)
     bbox = create_vbuttonbox (parent);
     gtk_box_pack_start (GTK_BOX (hbox), bbox, FALSE, TRUE, 0);
 
-    button = create_button (parent, _("_Add..."), GTK_SIGNAL_FUNC (on_device_add));
+    button = create_stock_button (parent, GTK_STOCK_ADD, GTK_SIGNAL_FUNC (on_device_add));
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_container_add (GTK_CONTAINER (bbox), button);
 
-    button = create_button (parent, _("_Edit..."), GTK_SIGNAL_FUNC (on_device_edit));
+    button = create_stock_button (parent, GTK_STOCK_EDIT, GTK_SIGNAL_FUNC (on_device_edit));
     gtk_object_set_data (GTK_OBJECT (parent), "edit_device_button", button);
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_widget_set_sensitive (button, FALSE);
     gtk_container_add (GTK_CONTAINER (bbox), button);
 
-    button = create_button (parent, _("_Remove"), GTK_SIGNAL_FUNC (on_device_remove));
+    button = create_stock_button (parent, GTK_STOCK_REMOVE, GTK_SIGNAL_FUNC (on_device_remove));
     gtk_object_set_data (GTK_OBJECT (parent), "remove_device_button", button);
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_widget_set_sensitive (button, FALSE);
@@ -1740,7 +1786,7 @@ create_devices_tab (GtkWidget *parent)
 
 
     clist = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (parent), "device_clist");
-    for (devices = gnome_cmd_con_list_get_all_dev (gnome_cmd_data_get_con_list ()); devices; devices = devices->next)
+    for (devices = gnome_cmd_con_list_get_all_dev (gnome_cmd_con_list_get ()); devices; devices = devices->next)
         if (!gnome_cmd_con_device_get_autovol((GnomeCmdConDevice *) devices->data))
             add_device_to_list (GTK_CLIST (clist), GNOME_CMD_CON_DEVICE (devices->data));
 
@@ -1748,8 +1794,7 @@ create_devices_tab (GtkWidget *parent)
 }
 
 
-static void
-store_devices_options (GtkWidget *dialog)
+inline void store_devices_options (GtkWidget *dialog)
 {
     GtkWidget *device_only_icon = lookup_widget (dialog, "device_only_icon");
     GtkWidget *skip_mounting = lookup_widget (dialog, "skip_mounting");
@@ -1769,6 +1814,7 @@ on_options_dialog_close (GtkButton *button, GtkWidget *dialog)
     store_layout_options (options_dialog);
     store_confirmation_options (options_dialog);
     store_filter_options (options_dialog);
+    store_network_options (options_dialog);
     store_programs_options (options_dialog);
     store_devices_options (dialog);
 
@@ -1847,6 +1893,7 @@ init (GnomeCmdOptionsDialog *dialog)
     gtk_container_add (GTK_CONTAINER (dialog->notebook), create_layout_tab (options_dialog));
     gtk_container_add (GTK_CONTAINER (dialog->notebook), create_confirmation_tab (options_dialog));
     gtk_container_add (GTK_CONTAINER (dialog->notebook), create_filter_tab (options_dialog));
+    gtk_container_add (GTK_CONTAINER (dialog->notebook), create_network_tab (options_dialog));
     gtk_container_add (GTK_CONTAINER (dialog->notebook), create_programs_tab (options_dialog));
     gtk_container_add (GTK_CONTAINER (dialog->notebook), create_devices_tab (options_dialog));
 
@@ -1875,6 +1922,11 @@ init (GnomeCmdOptionsDialog *dialog)
         gtk_notebook_get_nth_page (GTK_NOTEBOOK (dialog->notebook), GNOME_CMD_OPTIONS_DIALOG_TAB_FILTERS),
         gtk_label_new (_("Filters")));
 
+    gtk_notebook_set_tab_label (
+        GTK_NOTEBOOK (dialog->notebook),
+        gtk_notebook_get_nth_page (GTK_NOTEBOOK (dialog->notebook), GNOME_CMD_OPTIONS_DIALOG_TAB_NETWORK),
+        gtk_label_new (_("Network")));
+
     gtk_notebook_set_tab_label (
         GTK_NOTEBOOK (dialog->notebook),
         gtk_notebook_get_nth_page (GTK_NOTEBOOK (dialog->notebook), GNOME_CMD_OPTIONS_DIALOG_TAB_PROGRAMS),
